{
 "cells": [
  {
   "cell_type": "markdown",
   "id": "c5274f36-3b63-4ab2-ab36-037d9232c388",
   "metadata": {},
   "source": [
    "# Maneuver Loads\n",
    "\n",
    "In this section a maneuver loads simulation is going to be studied. The  simulation set-up in <em>Loads Kernel</em> was already shown in detail in a previous notebook. Hence, the focus will be more in the results and post processing."
   ]
  },
  {
   "cell_type": "markdown",
   "id": "e3a91932-9728-47cd-9c83-ebc245383f36",
   "metadata": {},
   "source": [
    "## Simulation Set-up\n",
    "\n",
    "The simulation set-up for the maneuver loads simulation is very similar to the set-up done for the trim analyses. The only difference is in the self.trimcase set up. In this case two extra maneuvers are included. The three maneuvers used for the trim cases were used: the horizontal level flight (n<sub>Z</sub>=1), the push-down maneuver (n<sub>Z</sub>=-1) and the pull-up maneuver (n<sub>Z</sub>=2.5). Additionally, two roll maneuvers were added. From CS-25 Amendment 28 {cite}`cs25`, the aircraft at trim with a 30◦ bank angle has to be able to roll to a 30◦ bank angle in the other direction in not more than 11 seconds. That corresponds to a roll velocity of p=5.45◦/s. A roll velocity of p=5.45◦/s is actually quiet slow and it does not produce very interesting results in the maneuver loads. For that reason, this roll maneuver is going to be performed in 3 seconds rather than 11. Hence, a roll velocity of p=20◦/s. All these maneuvers were performed at True Airspeed (TAS) of 70m/s and Flight Level FL000. This trim velocity was chosen again because is roughly the middle point between the maneuvering speed V<sub>A</sub>=113KEAS=58.13m/s and the design speed for maximum gust intensity V<sub>B</sub>=170KEAS=87.46m/s."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "375cd0f5-e922-4dca-829d-3dd411f4513e",
   "metadata": {},
   "outputs": [],
   "source": [
    "class jcl:\n",
    "\n",
    "    def __init__(self):\n",
    "\n",
    "        self.trimcase = [{'desc': 'CC.M3.OVCFL000.level', # Descriptive string of the maneuver case\n",
    "                          # Kind of trim condition, blank for trim about all three axes, for more trim conditions see\n",
    "                          # trim_conditions.py\n",
    "                          'maneuver': '',\n",
    "                          # Subcase ID number, for Nastran in acending order\n",
    "                          'subcase': 1,\n",
    "                          # Setting of the operational point\n",
    "                          # The flight speed is given by the Mach number\n",
    "                          'Ma': tas2Ma(70.0, 0.0),\n",
    "                          # Aero key\n",
    "                          'aero': 'VC',\n",
    "                          # Atmo key\n",
    "                          'altitude': 'FL000',\n",
    "                          # Mass key\n",
    "                          'mass': 'M3',\n",
    "                          # Load factor Nz\n",
    "                          'Nz': 1.0,\n",
    "                          # Velocities and accelerations given in ISO 9300 coordinate system (right-handed, forward-right-down)\n",
    "                          # Roll rate in rad/s\n",
    "                          'p': 0.0 / 180.0 * np.pi,\n",
    "                          # Pitch rate in rad/s\n",
    "                          'q': 0.0 / 180.0 * np.pi,\n",
    "                          # Yaw rate in rad/s\n",
    "                          'r': 0.0,\n",
    "                          # Roll acceleration in rad/s^2\n",
    "                          'pdot': 0.0 ,\n",
    "                          # Pitch acceleration in rad/s^2\n",
    "                          'qdot': 0.0,\n",
    "                          # Yaw acceleration in rad/s^2\n",
    "                          'rdot': 0.0,\n",
    "                          },\n",
    "                         {'desc': 'CC.M3.OVCFL000.pushdown',  # Descriptive string of the maneuver case\n",
    "                          # Kind of trim condition, blank for trim about all three axes, for more trim conditions see\n",
    "                          # trim_conditions.py\n",
    "                          'maneuver': '',\n",
    "                          # Subcase ID number, for Nastran in acending order\n",
    "                          'subcase': 2,\n",
    "                          # Setting of the operational point\n",
    "                          # The flight speed is given by the Mach number\n",
    "                          'Ma': tas2Ma(70.0, 0.0),\n",
    "                          # Aero key\n",
    "                          'aero': 'VC',\n",
    "                          # Atmo key\n",
    "                          'altitude': 'FL000',\n",
    "                          # Mass key\n",
    "                          'mass': 'M3',\n",
    "                          # Load factor Nz\n",
    "                          'Nz': -1.0,\n",
    "                          # Velocities and accelerations given in ISO 9300 coordinate system (right-handed, forward-right-down)\n",
    "                          # Roll rate in rad/s\n",
    "                          'p': 0.0 / 180.0 * np.pi,\n",
    "                          # Pitch rate in rad/s\n",
    "                          'q': 0.0 / 180.0 * np.pi,\n",
    "                          # Yaw rate in rad/s\n",
    "                          'r': 0.0,\n",
    "                          # Roll acceleration in rad/s^2\n",
    "                          'pdot': 0.0,\n",
    "                          # Pitch acceleration in rad/s^2\n",
    "                          'qdot': 0.0,\n",
    "                          # Yaw acceleration in rad/s^2\n",
    "                          'rdot': 0.0,\n",
    "                          },\n",
    "                         {'desc': 'CC.M3.OVCFL000.pullup',  # Descriptive string of the maneuver case\n",
    "                          # Kind of trim condition, blank for trim about all three axes, for more trim conditions see\n",
    "                          # trim_conditions.py\n",
    "                          'maneuver': '',\n",
    "                          # Subcase ID number, for Nastran in acending order\n",
    "                          'subcase': 3,\n",
    "                          # Setting of the operational point\n",
    "                          # The flight speed is given by the Mach number\n",
    "                          'Ma': tas2Ma(70.0, 0.0),\n",
    "                          # Aero key\n",
    "                          'aero': 'VC',\n",
    "                          # Atmo key\n",
    "                          'altitude': 'FL000',\n",
    "                          # Mass key\n",
    "                          'mass': 'M3',\n",
    "                          # Load factor Nz\n",
    "                          'Nz': 2.5,\n",
    "                          # Velocities and accelerations given in ISO 9300 coordinate system (right-handed, forward-right-down)\n",
    "                          # Roll rate in rad/s\n",
    "                          'p': 0.0,\n",
    "                          # Pitch rate in rad/s\n",
    "                          'q': 0.0,\n",
    "                          # Yaw rate in rad/s\n",
    "                          'r': 0.0,\n",
    "                          # Roll acceleration in rad/s^2\n",
    "                          'pdot': 0.0,\n",
    "                          # Pitch acceleration in rad/s^2\n",
    "                          'qdot': 0.0,\n",
    "                          # Yaw acceleration in rad/s^2\n",
    "                          'rdot': 0.0,\n",
    "                          },\n",
    "                         {'desc': 'CC.M3.OVCFL000.roll_right',  # Descriptive string of the maneuver case\n",
    "                          # Kind of trim condition, blank for trim about all three axes, for more trim conditions see\n",
    "                          # trim_conditions.py\n",
    "                          'maneuver': '',\n",
    "                          # Subcase ID number, for Nastran in acending order\n",
    "                          'subcase': 4,\n",
    "                          # Setting of the operational point\n",
    "                          # The flight speed is given by the Mach number\n",
    "                          'Ma': tas2Ma(70.0, 0.0),\n",
    "                          # Aero key\n",
    "                          'aero': 'VC',\n",
    "                          # Atmo key\n",
    "                          'altitude': 'FL000',\n",
    "                          # Mass key\n",
    "                          'mass': 'M3',\n",
    "                          # Load factor Nz\n",
    "                          'Nz': 1.0,\n",
    "                          # Velocities and accelerations given in ISO 9300 coordinate system (right-handed, forward-right-down)\n",
    "                          # Roll rate in rad/s\n",
    "                          'p': 0.349,\n",
    "                          # Pitch rate in rad/s\n",
    "                          'q': 0.0,\n",
    "                          # Yaw rate in rad/s\n",
    "                          'r': 0.0,\n",
    "                          # Roll acceleration in rad/s^2\n",
    "                          'pdot': 0.0,\n",
    "                          # Pitch acceleration in rad/s^2\n",
    "                          'qdot': 0.0,\n",
    "                          # Yaw acceleration in rad/s^2\n",
    "                          'rdot': 0.0,\n",
    "                          },\n",
    "                         {'desc': 'CC.M3.OVCFL000.roll_left',  # Descriptive string of the maneuver case\n",
    "                          # Kind of trim condition, blank for trim about all three axes, for more trim conditions see\n",
    "                          # trim_conditions.py\n",
    "                          'maneuver': '',\n",
    "                          # Subcase ID number, for Nastran in acending order\n",
    "                          'subcase': 5,\n",
    "                          # Setting of the operational point\n",
    "                          # The flight speed is given by the Mach number\n",
    "                          'Ma': tas2Ma(70.0, 0.0),\n",
    "                          # Aero key\n",
    "                          'aero': 'VC',\n",
    "                          # Atmo key\n",
    "                          'altitude': 'FL000',\n",
    "                          # Mass key\n",
    "                          'mass': 'M3',\n",
    "                          # Load factor Nz\n",
    "                          'Nz': 1.0,\n",
    "                          # Velocities and accelerations given in ISO 9300 coordinate system (right-handed, forward-right-down)\n",
    "                          # Roll rate in rad/s\n",
    "                          'p': -0.349,\n",
    "                          # Pitch rate in rad/s\n",
    "                          'q': 0.0,\n",
    "                          # Yaw rate in rad/s\n",
    "                          'r': 0.0,\n",
    "                          # Roll acceleration in rad/s^2\n",
    "                          'pdot': 0.0,\n",
    "                          # Pitch acceleration in rad/s^2\n",
    "                          'qdot': 0.0,\n",
    "                          # Yaw acceleration in rad/s^2\n",
    "                          'rdot': 0.0,\n",
    "                          }]\n",
    "        \n",
    "        self.simcase  = jcl_helper.generate_empty_listofdicts(self.trimcase)\n",
    "        # End\n"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "f95369ce-148b-427a-a6e9-034715011bbb",
   "metadata": {},
   "source": [
    "In order to obtain the results the following 'launch.py' file is run. The results can be found in the folder 'DC-3_results'."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "38c976bf-f470-4c0f-b41e-c0c07d739e85",
   "metadata": {
    "tags": [
     "skip-execution"
    ]
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "INFO: This is the log for process 0.\n",
      "INFO: Starting Loads Kernel with job: jcl_dc3_maneuvers\n",
      "INFO: User carn_fr on schwalbe (Linux-4.18.0-513.24.1.el8_9.x86_64-x86_64-with-glibc2.28)\n",
      "INFO: pre:  True\n",
      "INFO: main: True\n",
      "INFO: post: True\n",
      "INFO: test: False\n",
      "INFO: --> Reading parameters from JCL.\n",
      "INFO: Generated list of 5 empty dicts.\n",
      "INFO: --> Starting preprocessing.\n",
      "INFO: Building structural model...\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/structure_only.bdf\n",
      "INFO: Found include(s):\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/export_FUS.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-wing/left-wing.GRID_LREFAX_5400001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-wing/left-wing.RBE2_LREFAX_5400001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-wing/left-wing.CORD2R_LREFAX\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-wing/left-wing.MAT_ZR\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-wing/export_left-wing.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-wing/right-wing.GRID_LREFAX_6400001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-wing/right-wing.RBE2_LREFAX_6400001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-wing/right-wing.CORD2R_LREFAX\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-wing/right-wing.MAT_ZR\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-wing//export_right-wing.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-ht/left-ht.GRID_LREFAX_3330001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-ht/left-ht.RBE2_LREFAX_3330001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-ht/left-ht.CORD2R_LREFAX\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-ht/left-ht.MAT_ZR\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/left-ht/export_left-ht.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-ht/right-ht.GRID_LREFAX_3340001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-ht/right-ht.RBE2_LREFAX_3340001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-ht/right-ht.CORD2R_LREFAX\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-ht/right-ht.MAT_ZR\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/right-ht/export_right-ht.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/vt/vt.GRID_LREFAX_3320001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/vt/vt.RBE2_LREFAX_3320001\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/vt/vt.CORD2R_LREFAX\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/vt/vt.MAT_ZR\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/vt/export_vt.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/export_left-nacell.csv\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/../fem/export_right-nacell.csv\n",
      "INFO: The structural model consists of 278 grid points (1668 DoFs) and 7 coordinate systems.\n",
      "INFO: Reading Monitoring Stations from MONPNTs...\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/export_monitoring-stations.csv\n",
      "INFO: Splining (rigid body) of 1668 DOFs to 192 DOFs...\n",
      "INFO: Building atmo model...\n",
      "INFO: Building aero model...\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/vt/vt.CAERO1\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/left-ht/left-ht.CAERO1\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/right-ht/right-ht.CAERO1\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/left-wing/left-wing.CAERO1\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/right-wing/right-wing.CAERO1\n",
      "INFO: Constructing aero panels from CAERO cards\n",
      "INFO:  - from corner points and aero panels, constructing aerogrid\n",
      "INFO: Read W2GJ data from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/w2gj_list.DMI_merge\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6336 DOFs...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6336 DOFs...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6 DOFs...\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/vt/vt.AESURF\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/left-ht/left-ht.AESURF\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/right-ht/right-ht.AESURF\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/left-wing/left-wing.AESURF\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/right-wing/right-wing.AESURF\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/vt/vt.AELIST\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/left-ht/left-ht.AELIST\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/right-ht/right-ht.AELIST\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/left-wing/left-wing.AELIST\n",
      "INFO: Read from file: /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/aero/right-wing/right-wing.AELIST\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 6 DOFs...\n",
      "INFO: Calculating steady AIC matrices (1056 panels, k=0.0) for 2 Mach number(s)...\n",
      "INFO: done in 1.04 [sec].\n",
      "INFO: The aerodynamic model consists of 1056 panels and 5 control surfaces.\n",
      "INFO: Coupling aerogrid directly. Doing cleanup/thin out of strcgrid to avoid singularities                     (safety first!)\n",
      "INFO: The spline model consists of 272 grid points.\n",
      "INFO: Searching nearest neighbour of 1056 dependent nodes in 272 independent nodes...\n",
      "INFO: Splining (rigid body) of 6336 DOFs to 1668 DOFs...\n",
      "INFO: Building stiffness and mass model...\n",
      "INFO: Reading matrix KGG from /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/SOL103_structure_only.mtx.h5\n",
      "INFO: Reading matrix GM from /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/SOL103_structure_only.mtx.h5\n",
      "INFO: Read USET from OP2-file /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/uset.op2 ...\n",
      "Table  USET    , bytes =       6935 [         0 to       6936]\n",
      "INFO: Extracting bit positions from USET to determine DoFs\n",
      "INFO: Prepare stiffness matrices for independent and free DoFs (f-set)\n",
      "INFO: Mass configuration 1 of 1: M3 \n",
      "INFO: Reading matrix MGG from /data/carn_fr/LoadsKernel/doc/tutorials/DC3_model/fem/SOL103_M3.mtx.h5\n",
      "INFO: Calculate center of gravity, mass and inertia (GRDPNT)...\n",
      "INFO: Splining (rigid body) of 1668 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 1668 DOFs to 6 DOFs...\n",
      "INFO: Mass: 11883.983000000002\n",
      "INFO: CG at: [8.62280419e+00 5.43474355e-08 3.11704131e-01]\n",
      "INFO: Inertia: \n",
      "[[ 6.93201323e+04 -3.80956656e-04  1.17729353e+04]\n",
      " [-3.80956654e-04  1.40925492e+05 -1.74794555e-04]\n",
      " [ 1.17729353e+04 -1.74794555e-04  1.97104534e+05]]\n",
      "INFO: Prepare mass matrices for independent and free DoFs (f-set)\n",
      "INFO: Modal analysis for first 76 modes...\n",
      "INFO: Found 76 modes with the following frequencies [Hz]:\n",
      "INFO: [           nan            nan 1.05457802e-06 4.52538930e-06\n",
      " 1.45457362e-05 3.39333114e-05 3.13716140e+00 4.68251648e+00\n",
      " 7.20798842e+00 7.88159198e+00 8.33703334e+00 8.49130434e+00\n",
      " 9.88499185e+00 1.25695152e+01 1.53520000e+01 1.70224904e+01\n",
      " 1.71353125e+01 1.84415883e+01 2.53323405e+01 2.53529787e+01\n",
      " 2.68433851e+01 2.81886245e+01 3.20724571e+01 3.24562324e+01\n",
      " 3.51081211e+01 3.52877859e+01 3.71484020e+01 3.74387461e+01\n",
      " 4.65087795e+01 4.66555395e+01 5.19704569e+01 5.31897897e+01\n",
      " 5.59827047e+01 5.61588818e+01 5.79161872e+01 5.83859187e+01\n",
      " 6.49254027e+01 6.49636994e+01 6.52953993e+01 6.55893563e+01\n",
      " 6.76977070e+01 7.39272939e+01 7.40020584e+01 7.92493678e+01\n",
      " 7.98448917e+01 8.44686963e+01 8.44977700e+01 8.89696420e+01\n",
      " 8.90380160e+01 9.17266784e+01 9.27516791e+01 1.00718906e+02\n",
      " 1.00742526e+02 1.05800840e+02 1.06520421e+02 1.09898735e+02\n",
      " 1.10071029e+02 1.12603325e+02 1.12677121e+02 1.21628942e+02\n",
      " 1.21633308e+02 1.25797288e+02 1.25826624e+02 1.30369009e+02\n",
      " 1.30516978e+02 1.37566261e+02 1.37608584e+02 1.41676350e+02\n",
      " 1.44303157e+02 1.44811563e+02 1.47038007e+02 1.47151873e+02\n",
      " 1.55547154e+02 1.56081100e+02 1.56183006e+02 1.57181628e+02]\n",
      "INFO: From these 76 modes, the following 70 modes are selected: [ 7  8  9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30\n",
      " 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54\n",
      " 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76]\n",
      "INFO: Working on f-set\n",
      "INFO: Damping: modal damping of 0.02\n",
      "INFO: Working on h-set\n",
      "INFO: Splining (rigid body) of 1668 DOFs to 6 DOFs...\n",
      "INFO: Damping: modal damping of 0.02\n",
      "INFO: Splining (rigid body) of 1668 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6 DOFs to 6 DOFs...\n",
      "INFO: Splining (rigid body) of 6 DOFs to 6 DOFs...\n",
      "INFO: --> Saving model data.\n",
      "INFO: --> Done in 0:00:04 [h:mm:ss].\n",
      "INFO: --> Starting Main in sequential mode for 5 trimcase(s).\n",
      "INFO: \n",
      "INFO: ========================================\n",
      "INFO: trimcase: CC.M3.OVCFL000.level\n",
      "INFO: subcase: 1\n",
      "INFO: (case 1 of 5)\n",
      "INFO: ========================================\n",
      "INFO: Setting trim conditions to \"default\"\n",
      "INFO: Init model equations of type \"Steady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: Running trim for 76 variables...\n",
      "INFO: The solution converged.\n",
      "INFO: calculating forces & moments on structural set (force summation method)...\n",
      "INFO: apply euler angles...\n",
      "INFO: calculating cutting forces & moments...\n",
      "INFO: gathering information on monitoring stations from response(s)...\n",
      "INFO: searching min/max in time data at 32 monitoring stations and gathering loads (dyn2stat)...\n",
      "INFO: --> Saving response(s).\n",
      "INFO: \n",
      "INFO: ========================================\n",
      "INFO: trimcase: CC.M3.OVCFL000.pushdown\n",
      "INFO: subcase: 2\n",
      "INFO: (case 2 of 5)\n",
      "INFO: ========================================\n",
      "INFO: Setting trim conditions to \"default\"\n",
      "INFO: Init model equations of type \"Steady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: Running trim for 76 variables...\n",
      "INFO: The solution converged.\n",
      "INFO: calculating forces & moments on structural set (force summation method)...\n",
      "INFO: apply euler angles...\n",
      "INFO: calculating cutting forces & moments...\n",
      "INFO: gathering information on monitoring stations from response(s)...\n",
      "INFO: searching min/max in time data at 32 monitoring stations and gathering loads (dyn2stat)...\n",
      "INFO: --> Saving response(s).\n",
      "INFO: \n",
      "INFO: ========================================\n",
      "INFO: trimcase: CC.M3.OVCFL000.pullup\n",
      "INFO: subcase: 3\n",
      "INFO: (case 3 of 5)\n",
      "INFO: ========================================\n",
      "INFO: Setting trim conditions to \"default\"\n",
      "INFO: Init model equations of type \"Steady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: Running trim for 76 variables...\n",
      "INFO: The solution converged.\n",
      "INFO: calculating forces & moments on structural set (force summation method)...\n",
      "INFO: apply euler angles...\n",
      "INFO: calculating cutting forces & moments...\n",
      "INFO: gathering information on monitoring stations from response(s)...\n",
      "INFO: searching min/max in time data at 32 monitoring stations and gathering loads (dyn2stat)...\n",
      "INFO: --> Saving response(s).\n",
      "INFO: \n",
      "INFO: ========================================\n",
      "INFO: trimcase: CC.M3.OVCFL000.roll_right\n",
      "INFO: subcase: 4\n",
      "INFO: (case 4 of 5)\n",
      "INFO: ========================================\n",
      "INFO: Setting trim conditions to \"default\"\n",
      "INFO: Init model equations of type \"Steady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: Running trim for 76 variables...\n",
      "INFO: The solution converged.\n",
      "INFO: calculating forces & moments on structural set (force summation method)...\n",
      "INFO: apply euler angles...\n",
      "INFO: calculating cutting forces & moments...\n",
      "INFO: gathering information on monitoring stations from response(s)...\n",
      "INFO: searching min/max in time data at 32 monitoring stations and gathering loads (dyn2stat)...\n",
      "INFO: --> Saving response(s).\n",
      "INFO: \n",
      "INFO: ========================================\n",
      "INFO: trimcase: CC.M3.OVCFL000.roll_left\n",
      "INFO: subcase: 5\n",
      "INFO: (case 5 of 5)\n",
      "INFO: ========================================\n",
      "INFO: Setting trim conditions to \"default\"\n",
      "INFO: Init model equations of type \"Steady\"\n",
      "INFO: Init EFCS \"efcs_dc3\"\n",
      "INFO: Running trim for 76 variables...\n",
      "INFO: The solution converged.\n",
      "INFO: calculating forces & moments on structural set (force summation method)...\n",
      "INFO: apply euler angles...\n",
      "INFO: calculating cutting forces & moments...\n",
      "INFO: gathering information on monitoring stations from response(s)...\n",
      "INFO: searching min/max in time data at 32 monitoring stations and gathering loads (dyn2stat)...\n",
      "INFO: --> Saving response(s).\n",
      "INFO: --> Saving monstation(s).\n",
      "INFO: --> Saving dyn2stat.\n",
      "INFO: --> Done in 0:00:04 [h:mm:ss].\n",
      "INFO: --> Opening response(s).\n",
      "INFO: --> Loading monstations(s).\n",
      "INFO: --> Loading dyn2stat.\n",
      "INFO: --> Drawing some standard plots.\n",
      "INFO: start potato-plotting...\n",
      "INFO: start plotting cutting forces along wing...\n",
      "INFO: plots saved as ./DC3_results/monstations_jcl_dc3_maneuvers.pdf\n",
      "INFO: --> Saving auxiliary output data.\n",
      "INFO: writing trim results to: ./DC3_results/trim_results_jcl_dc3_maneuvers.csv\n",
      "INFO: writing successful trimcases cases to: ./DC3_results/successful_trimcases_jcl_dc3_maneuvers.csv\n",
      "INFO: writing failed trimcases cases to: ./DC3_results/failed_trimcases_jcl_dc3_maneuvers.csv\n",
      "INFO: writing critical trimcases cases to: ./DC3_results/crit_trimcases_jcl_dc3_maneuvers.csv\n",
      "INFO: saving critical nodal loads as Nastarn cards...\n",
      "INFO: Loads Kernel finished.\n",
      "INFO: \n",
      "INFO:        (  )\n",
      "INFO:       (    )\n",
      "INFO: \n",
      "INFO:               (   )\n",
      "INFO:              (     )\n",
      "INFO: \n",
      "INFO:          _|_\n",
      "INFO:  ---------O---------\n",
      "INFO: \n",
      "INFO: \n"
     ]
    }
   ],
   "source": [
    "from loadskernel import program_flow\n",
    "\n",
    "# Here you launch the Loads Kernel with your job\n",
    "k = program_flow.Kernel('jcl_dc3_maneuvers', pre=True, main=True, post=True, test=False,\n",
    "                        path_input='./DC3_model/JCLs',\n",
    "                        path_output='./DC3_results')\n",
    "k.run()"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "db6a4dc7-b1ed-4f33-8b06-a49ad44aca80",
   "metadata": {},
   "source": [
    "## Results\n",
    "\n",
    "The resulting nodal loads were integrated at designated monitoring stations along the wing span to derive section loads, utilizing the <em>Loads Kernel</em>. In this section only the <em>Loads Kernel</em> results are analysed, since in the previous section the verisimilitude between <em>MCS Nastran</em> and <em>Loads Kernel</em> was proved. A total of 16 monitoring stations were strategically placed on each wing. Key quantities of interest for the wing include the bending moment M<sub>x</sub>, torsional moment M<sub>y</sub>, and shear force F<sub>z</sub>.\n",
    "\n",
    "To identify the critical load cases, two-dimensional load envelopes were constructed, illustrating combinations of two significant section loads. For the wing, the pertinent load envelopes are F<sub>z</sub>/M<sub>x</sub> and M<sub>x</sub>/M<sub>y</sub>  . But only the M<sub>x</sub>/M<sub>y</sub> load envelope is going to be analysed. Given the wing’s configuration with an outboard section featuring sweep and a rectangular inboard section, section loads were computed in the global coordinate system (x-y-z directions: aft-right-up) for the inboard section, and in a local coordinate system for the outboard section.\n",
    "\n",
    "For instance, next figure illustrates the load envelope detailing the torsional moment M<sub>y</sub> and bending moment M<sub>x</sub> at the wing root. It is evident that the most significant negative bending moment M<sub>x</sub> aligns with the pull-up maneuver, while the highest positive bending moment M<sub>x</sub> corresponds to the push-down maneuver. Similarly, regarding the torsional moment M<sub>y</sub> , the peak negative torsional moment M<sub>y</sub> coincides with the pull-up maneuver, and the maximum positive torsional moment M<sub>y</sub> aligns with the push-down maneuver.\n",
    "\n",
    "Furthermore, it’s noticeable that the roll maneuvers exhibit identical bending moments M<sub>x</sub> to horizontal level flight since the load factor remains constant at n<sub>Z</sub>=1 for all three maneuvers. However, in terms of the torsional moment M<sub>y</sub> , the roll maneuvers display an offset (one for each side) compared to horizontal level flight. This outcome was anticipated as the roll maneuver involves aileron deflection, contributing to an increase in elastic wing twist.\n",
    "\n",
    "<img src=\"./images/MxMy.png\" width=\"400\" alt=\"DC3\">\n",
    "\n",
    "*Bending moment M<sub>x</sub> and torsional moment M<sub>y</sub> at the wing root.*\n",
    "\n",
    "Moreover, one-dimensional envelopes along the wing span provide insights into the evolution of section loads across the wing. Next figure illustrates the envelope of the bending moment M<sub>x</sub> along the wing span, with each red dot denoting the highest positive and negative bending moment at each monitoring station. A comparison between the results for the right and left wings reveals symmetrical bending moments with reversed signs, attributable to the rearward orientation of the x-axis in the coordinate system for both sides. In the left wing, the most significant negative bending moment arises from the pull-up maneuver with a load factor of n<sub>Z</sub>=2.5. Conversely, the largest positive bending moment stems from the push-down maneuver with a load factor of n<sub>Z</sub>=-1. Hence, a negative sign denotes an upward bending moment, while a positive sign indicates a downward bending moment. Conversely, for the right wing, the opposite occurs due to the definition of the x-axis. This outcome aligns with expectations, as the pull-up maneuver induces upward wing bending, while the push-down maneuver leads to downward bending. The highest bending moments M<sub>x</sub> are at the root as expected.\n",
    "\n",
    "<img src=\"./images/Mx_y.png\" width=\"400\" alt=\"DC3\">\n",
    "\n",
    "*Bending moment M<sub>x</sub> along the wing span.*\n",
    "\n",
    "For additional information about the meanuver load results please refer to {cite}`Carvalho2024`."
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.10.13"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
